Learn R Programming

fdars (version 0.3.3)

kernel.whitenoise: White Noise Covariance Function

Description

Computes the white noise covariance function: $$k(s, t) = \sigma^2 \mathbf{1}_{s = t}$$

Usage

kernel.whitenoise(variance = 1)

Value

A covariance function object of class 'kernel_whitenoise'.

Arguments

variance

Variance (noise level) parameter \(\sigma^2\) (default 1).

Details

where \(\mathbf{1}_{s = t}\) is 1 if \(s = t\) and 0 otherwise.

The white noise covariance function represents independent noise at each point. It can be added to other covariance functions to model observation noise.

See Also

kernel.gaussian, make.gaussian.process

Examples

Run this code
# White noise covariance produces independent samples at each point
cov_func <- kernel.whitenoise(variance = 0.1)
t <- seq(0, 1, length.out = 50)
K <- cov_func(t)
# K is diagonal

Run the code above in your browser using DataLab