A covariance function object of class 'kernel_brownian'.
Arguments
variance
Variance parameter \(\sigma^2\) (default 1).
Details
The Brownian motion covariance produces sample paths that start at 0
and have independent increments. The covariance between two points
equals the variance times the minimum of their positions.
This covariance is only defined for 1D domains starting at 0.