powered by
Simulate sample paths from a Brownian bridge, which is a Brownian motion conditioned to return to 0 at time 1.
r.bridge(n, t, sigma = 1, seed = NULL)
An fdata object containing the simulated paths.
Number of sample paths.
Evaluation points (should include 0 and 1 for standard bridge).
Volatility (default 1).
Optional random seed.
t <- seq(0, 1, length.out = 100) bb_data <- r.bridge(n = 20, t = t) plot(bb_data)
Run the code above in your browser using DataLab